@@ -2,7 +2,7 @@
 * dvbpsi.cpp: common tools to use the libdvbpsi
 *-------------------------------------------------------------------------------
 * (c)1999-2002 VideoLAN
-* $Id: dvbpsi.cpp,v 1.7 2002/10/07 15:01:22 sam Exp $
+* $Id: dvbpsi.cpp,v 1.7.4.1 2003/11/20 20:03:30 nitrox Exp $
 *
 * Authors: Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
 *
@@ -119,7 +119,7 @@ void C_DvbPsiTable::TsWrite(C_TsPacket *pPacket)
                         + (m_pCurrentSection->b_syntax_indicator ? 4 : 0);
 
   pPosInTs[0] = 0x47;
-  pPosInTs[1] =   (m_pPosInSection == m_pCurrentSection->p_data) ? 0x40 : 0x00
+  pPosInTs[1] = ((m_pPosInSection == m_pCurrentSection->p_data) ? 0x40 : 0x00)
                 | m_iPid >> 8;
   pPosInTs[2] = m_iPid;
   pPosInTs[3] = 0x10 | m_iContinuityCounter;
