@@ -2,7 +2,7 @@
 * ps2ts.cpp: MPEG1 and MPEG2 PS to MPEG2 TS converter
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: ps2ts.cpp,v 1.4.4.2 2003/06/24 23:56:56 nitrox Exp $
+* $Id: ps2ts.cpp,v 1.4.4.3 2004/02/16 11:09:57 bigben Exp $
 *
 * Authors: Benoit Steiner <benny@via.ecp.fr>
 *          Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
@@ -564,9 +564,8 @@ template <class Reader, class TsProvider>
                                             m_iDataType & 0xFF, iPrivateId);
           u16 iPid =  m_pCurrentData->GetPid();
           u16 iData = U16_AT(*(pPacket + 1));
-          switch(iPrivateId)
+          if (iPrivateId <= 0x8f && iPrivateId >= 0x80)//A52
           {
-              case 0x80: //A52
                   // Add 4 bytes stuffing in the TS packet
                   // We have already written the PES start code and the PES
                   // length at the beginning of the TS packet but they will be
@@ -589,16 +588,15 @@ template <class Reader, class TsProvider>
                   *((byte*)(pPacket) + 3) =
                                     (m_pCurrentData->GetCounter() & 0x0f) |
                                     (*((byte*)(pPacket) + 3) & 0xf0);
-                  break;
-
-              default:
+          }
+          else
+          {
                   memcpy((byte*)(*pPacket)+iPos, pBuff, TS_PACKET_LEN-iPos);
                   iPid = (iPid & 0x1fff) | (iData & 0xe000);
                   SET_U16_TO(*((byte*)(pPacket) + 1), iPid);
                   *((byte*)(pPacket) + 3) =
                                     (m_pCurrentData->GetCounter() & 0x0f) |
                                     (*((byte*)(pPacket) + 3) & 0xf0);
-                  break;
           }
       }
       else
